@@ -114,7 +114,7 @@ class _CreateCategoricalEncodedVariables(DoFn):
         with open('load_email_lbe.pkl', 'rb') as f:
             email_lbe = pickle.load(f)
 
-        download_blob("load_transforms", "load_email_ohe.pkl", "load_equipment_mlb.pkl")
+        download_blob("load_transforms", "load_email_ohe.pkl", "load_email_ohe.pkl")
         with open('load_email_ohe.pkl', 'rb') as f:
             email_ohe = pickle.load(f)
 
